@@ -58,7 +58,13 @@ def runMain(moduleName=None, **parDict):
 def run(moduleName, **parDict):
     exec(f"import {moduleName}")
     module = eval(moduleName)
-    module.run(**parDict)
+    try:
+        module.run(**parDict)
+    except Exception as e:
+        raise e
+    finally:
+        if hasattr(module, "clean"):
+            module.clean()
 
 
 def initParDict():
